<!-- warning: Please don't edit this file. It was automatically generated. -->

# winrt-Windows.Security.Cryptography.Certificates

Windows Runtime (WinRT) APIs for for the `Windows.Security.Cryptography.Certificates` namespace.

This package provides the `winrt.windows.security.cryptography.certificates` module.
